#
# spec file for package ledmon
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ledmon
Version:        0.93
Release:        lp152.1.3
Summary:        Enclosure LED Utilities
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            https://github.com/intel/ledmon/
Source0:        https://github.com/intel/ledmon/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM ledmon-amd_sgpio.patch
Patch0:         Don-t-build-with-Werror.patch
Patch1:         ledmon-paths-in-systemd-service-file-are-generated.patch
Patch2:         smp-fix-the-activity-indicator-states.patch
Patch3:         amd_sgpio-Correct-use-of-packed-structs.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libsgutils-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(systemd)
Provides:       sgpio:/sbin/ledmon
Provides:       sgpio:/{%{_bindir}}/ledctl
%{?systemd_requires}

%description
The ledctl application and ledmon daemon are part of Intel(R) LED
ControlUtilities. They help to enable LED management for software RAID
solutions.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
autoreconf -fiv
%configure \
  --enable-systemd=yes
%make_build

%install
%make_install
rm %{buildroot}%{_datarootdir}/doc/ledmon/README

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc README
%{_sbindir}/ledmon
%{_sbindir}/ledctl
%{_unitdir}/ledmon.service
%{_mandir}/man5/ledmon.conf.5.5%{?ext_man}
%{_mandir}/man8/ledctl.8.8%{?ext_man}
%{_mandir}/man8/ledmon.8.8%{?ext_man}

%changelog
* Fri Dec 27 2019 heming.zhao@suse.com
- backport upstream patches to v0.93
  + Don-t-build-with-Werror.patch
  + ledmon-paths-in-systemd-service-file-are-generated.patch
  + smp-fix-the-activity-indicator-states.patch
- rename patch file
  - ledmon-amd_sgpio.patch
  + amd_sgpio-Correct-use-of-packed-structs.patch
* Tue Dec 17 2019 Martin Pluskal <mpluskal@suse.com>
- Fix download url
- Fix jira reference in changelog
- Add ledmon-amd_sgpio.patch to fix issues with building on TW
* Wed Dec 11 2019 Martin Pluskal <mpluskal@suse.com>
- Small packaging cleanups
* Wed Dec 11 2019 heming.zhao@suse.com
- Update to version 0.93 per jsc#SLE-8004
  * modified spec file according to changes in source code
- Enhancements
  * Support for AMD SGPIO enclosure management
  * Migration to GNU Autotools build system
  * Added more strict compilation flags
- Bug fixes
  * Fixed segfault when a value is missing from ibpi_str
  * Use proper format string with syslog()
  * Fixed issues reported by static analysis
  * Removed unused SGPIO structures
  * Added udev_device reference clean-up
  * Hidden ipmi error messages on non-dell platforms
* Thu Oct 10 2019 heming.zhao@suse.com
- Update to version 0.92 per https://jira.suse.de/browse/SLE-6784
- v0.92 changelog
  Bug fixes
  * Silence warning and error messages.
- v0.91 changelog
  Enhancements
  * Ledmon systemd service file.
  * Shared configuration between ledmon and ledctl.
  * Log-level support for ledctl.
  * Build label support.
  * 13G/14G Dell Servers support.
  * Foreground option.
  Bug fixes
  * Udev action handling reimplementation.
  * Unify ping process method.
  * Recognize volumes under reshape.
  * Distinguish inactive state for volume and container.
  * Fix various gcc and clang warnings.
  * Fix ledctl exit status.
  * Logging method reimplementation.
  * Makefile fixes.
  * Change outdated functions and simplify string modifications.
  * Ommited errors handling.
- Drop 0001-Recognize-RAID-volume-under-reshape-as-DEVICE_TYPE_V.patch
* Tue Oct 23 2018 gqjiang@suse.com
- Add a patch to fix bsc#1112539
  + 0001-Recognize-RAID-volume-under-reshape-as-DEVICE_TYPE_V.patch
* Thu Mar  8 2018 zlliu@suse.com
- Update to version 0.90:
  * No upstream changelog available
  * spec: deprecated ledctl.conf.5.gz and rename ledmon.conf.5.gz
  * add compile parameter -std=c99
- Drop 0001-fix-compilation-warnings-on-newer-gcc.patch
- bsc#1081125 and fate#322625
* Wed Dec 20 2017 coolo@suse.com
- disable parallel build, it fails more often than not
* Mon Nov 27 2017 zlliu@suse.com
- Update to version 0.81:
  * No upstream changelog available
  * add: 0001-fix-compilation-warnings-on-newer-gcc.patch
  * modify spec file on demand, add libudev dependency.
  * Intel has moved ledmon from Souceforge to Github.
- Drop no longer needed Makefile-error-dependency.patch
- Drop 0001-Don-t-rely-on-searching-for-block-in-sysfs-path-for-.patch
- bsc#1067452 and fate#322625
* Fri May 12 2017 zlliu@suse.com
- 0001-Don-t-rely-on-searching-for-block-in-sysfs-path-for-.patch
  Fixed bsc#1038655.
  upstream link of this patch:
  https://sourceforge.net/p/ledmon/code/ci/868a01
* Wed Mar 15 2017 zlliu@suse.com
- according to requirement by bsc#1029261 and fate#321489,
  Frederic suggested that it would better to add changlog
  here.
* Thu Dec 29 2016 mpluskal@suse.com
- Update to version 0.80:
  * No upstream changelog available
  * refresh Makefile-error-dependency.patch
- Drop no longer needed 0001-Recognize_bool_values_in_sysfs.patch
* Thu Jul 14 2016 zlliu@suse.com
- Fix bug bsc#986779, 0001-Recognize_bool_values_in_sysfs.patch.
  The type of libahci parameter ahci_em_messages was changed from
  int to bool in kernel v3.13, which caused AHCI HBAs to not be
  detected properly.
* Tue Jun  7 2016 normand@linux.vnet.ibm.com
- update Makefile-error-dependency.patch to avoid transient error
* Tue Jul 14 2015 werner@suse.de
- Let it build
* Mon Apr 20 2015 mpluskal@suse.com
- Use url for source
- Cleanupt spec file with spec-cleaner
* Mon Mar  2 2015 dimstar@opensuse.org
- Do not BuildRequire libsgutils2-2: pulling in the library is
  responsibility of the respective -devel packages.
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Thu Dec  5 2013 lzhong@suse.com
- update to version 0.79
  * remove not-send-command-if-status-not-changed.patch
  * remove fix-gcc-error.patch
  * add Makefile-error-dependency.patch
* Tue Mar  5 2013 lzhong@suse.com
- Add not-send-command-if-status-not-changed.patch(bnc#794489)
* Tue Feb  5 2013 lzhong@suse.com
- Update version from 0.75 to latest version 0.76(fate#313626) for sles-11-sp3
* Mon Jan 14 2013 lzhong@suse.com
- Update version from 0.74 to latest version 0.75(fate#313626) for sles-11-sp3
* Fri Nov 16 2012 lzhong@suse.com
- Initial check in (fate#313626) for sles-11-sp3
* Tue Jun 21 2011 xwhu@novell.com
- Initial check in (fate#311809)
